#include "agenda.h"
#include <stdlib.h>
#include <stdio.h>

int main(){
    Agenda *a=NULL;
    Persona *p=NULL;
    Data d;
    Vista *v=NULL;

    d.giorno.giorno=10;
    d.giorno.mese=12;
    d.giorno.anno=2018;
    d.ora.ora=14;
    d.ora.minuti=30;
    d.durata=120;
    a=ins_agenda(a, &p, "Paolino", "Paperino", d);
    d.ora.ora=15;
    a=ins_agenda(a, &p, "Gastone", "Paperone", d);
    d.giorno.giorno=11;
    a=ins_agenda(a, &p, "Pico", "De Paperis", d);
    d.ora.ora=9;
    a=ins_agenda(a, &p, "Paolino", "Paperino", d);
    d.ora.ora=12;
    a=ins_agenda(a, &p, "Gastone", "Paperone", d);

    d.giorno.giorno=8;
    a=ins_agenda(a, &p, "Paolino", "Paperino", d);

    print_agenda(a);
    printf("---------------------\n");

    v=select_persona(a, p, "Paolino", "Paperino");
    print_vista(v);
    free_vista(v);
    printf("---------------------\n");
    d.giorno.giorno=11;
    v=select_giorno(a, d.giorno);
    print_vista(v);
    free_vista(v);
}
